@@ -33,26 +33,31 @@ rosdep library and command-line tool
 
 from __future__ import print_function
 
-__version__ = '0.9.0'
+__version__ = '0.9.1'
 
 import sys
 
 try:
-    from .installers import InstallerContext, Installer, PackageManagerInstaller
-    from .core import RosdepInternalError, InstallFailed, UnsupportedOs, InvalidData, DownloadFailure
+    from .installers import InstallerContext, Installer, \
+            PackageManagerInstaller
+    from .core import RosdepInternalError, InstallFailed, UnsupportedOs, \
+            InvalidData, DownloadFailure
     from .model import RosdepDatabase, RosdepDatabaseEntry
-    from .lookup import RosdepDefinition, RosdepView, RosdepLookup, ResolutionError
+    from .lookup import RosdepDefinition, RosdepView, RosdepLookup, \
+            ResolutionError
     from .loader import RosdepLoader
 except ImportError:
     # soft-fail if rospkg not available.  Need this backoff behavior
     # in order to support setting __version__ in the module.
-    print("failed to load symbols, rosdep will not function properly", file=sys.stderr)
+    print("failed to load symbols, rosdep will not function properly",
+            file=sys.stderr)
 
 # don't let import error take down code as when attempting to compute version number
 try:
     from .rospkg_loader import RosPkgLoader
 except ImportError:
-    print("Cannot import rospkg, rosdep will not function properly", file=sys.stderr)
+    print("Cannot import rospkg, rosdep will not function properly", 
+            file=sys.stderr)
 
 
 def create_default_installer_context(verbose=False):
@@ -108,4 +113,13 @@ def get_default_installer(installer_context=None, verbose=False):
         raise UnsupportedOs(os_name, installer_context.get_os_keys())
     installer = installer_context.get_installer(default_key)
     return installer, installer_keys, default_key, os_name, os_version
-    
+
+__all__ = ['InstallerContext', 'Installer', 'PackageManagerInstaller',
+        'RosdepInternalError', 'InstallFailed', 'UnsupportedOs', 'InvalidData',
+        'DownloadFailure',
+        'RosdepDatabase', 'RosdepDatabaseEntry',
+        'RosdepDefinition', 'RosdepView', 'RosdepLookup', 'ResolutionError',
+        'RosdepLoader', 'RosPkgLoader',
+        'get_default_installer', 
+        'create_default_installer_context',
+        ]
