@@ -30,14 +30,11 @@
 import os
 import traceback
 from mock import Mock, patch
-from rosdep2.model import InvalidData
 
 def get_test_dir():
     # not used yet
     return os.path.abspath(os.path.join(os.path.dirname(__file__), 'gentoo'))
 
-from rospkg.os_detect import OsDetect, OS_GENTOO
-
 def test_portage_available():
     from rosdep2.platforms.gentoo import portage_available
 
